pype32.excep

Package pype32 :: Module excep |
[hide private]
[frames] | no frames]

# Module excep

source code

Exceptions used by the entire library.

Classes | [hide private]
Base exceptions
| PyPe32Exception Base exception class.
| PyPe32Warning Base warning class.
Warnings
| PEWarning Raised when a suspicious value is found into the PE instance.
Exceptions
| PEException Raised when an invalid field on the PE instance was found.
| NotValidPathException Raised when a path wasn't found or it is an invalid path.
| WrongOffsetValueException Used primary by the ReadData and WriteData object in read/write operations when an invalid offset value was used.
| DirectoryEntriesLengthException Raised when the the number of entries in a DataDirectory object is different from consts.IMAGE_NUMBEROF_DIRECTORY_ENTRIES.
| TypeNotSupportedException This exception must be used when an invalid data type is used within the library.
| ArrayTypeException Raised when creating an unsupported type of array.
| DataLengthException Raised when data lengths does not match.
| ReadDataOffsetException This exception must be raised when reading from an invalid offset.
| WriteDataOffsetException This exception must be raised when writing to an invalid offset.
| InstanceErrorException This exception is raised when an instance parameter was not specified.
| DataMismatchException Raised when two different types of data does not match.
| SectionHeadersException Raised when an error related to a pype32.SectionHeader or pype32.SectionHeaders is found.
| DirectoryEntryException This exception must be raised when an error with the Directory is found.
| InvalidParameterException Raised when an invalid parameter is received.

Variables | [hide private]
| __revision__ = ``'``$Id$``'``
| __package__ = `None` hash(x)